==> locus-0.84.tar.gz: locus-0.84/bin/grazer/formdisp.h <==
#if !defined(__formdisp_h)
#define __formdisp_h

#include "abstdisp.h"
#include <vector.h>
#include "rxw.h"

class CMirror;
class CResult;
class CGrazerOptions;
class DDocument;
class CRelevance;
class CClot;
class CPunctParse;

class CFormDisplay : public CAbstractDisplay
{
public:
    CFormDisplay(CMirror &aMirror,
	   CResult &aResult,
	   CGrazerOptions &aOptions);
    virtual ~CFormDisplay();

    virtual void Display();

private:
    CMirror &Mirror;
    CResult &Result;
    CGrazerOptions &Options;
    CFileObj OutFile;
    int SkipClots;
    CPunctParse *PunctParse;
    short TitlePart;
    CRegex Cruft;
    const DString HiddenHead;

    vector<char> TextColor;
    vector<char> OccColor;

    void DisplayUnindexed();
    void DisplayProlog();
    void DisplayEpilog();
    void DisplayDoc(DDocument *InDoc);
    void DisplayDocContents(DDocument *Doc);
    void DisplayRelevance(CRelevance *Relevance, double RelRes);
    int DisplayClot(CClot *Clot, int &HighlightCount);
    void DisplayPassage(const DString &Passage, 
        const char *Template);

    void ErrPrint(const vector<char> &Buffer);
    void OutPrint(const vector<char> &Buffer);

    int IsEmpty(const char *Name);

    vector<char>::const_iterator GetEscape(
	vector<char>::const_iterator Begin,
	vector<char>::const_iterator End);
    void PrintChars(
	vector<char>::const_iterator Begin,
	vector<char>::const_iterator End);
    void PrintEscape(vector<char>::const_iterator Escape);
    bool IsEscape(
	vector<char>::const_iterator Begin,
	vector<char>::const_iterator End);

    DString GetCleanText(const DString &RawText);
    DString GetTail(const DString &DocFileName);
};

#endif

==> locus-0.88.tar.gz: locus-0.88/bin/grazer/formdisp.h <==
#if !defined(__formdisp_h)
#define __formdisp_h

#include "abstdisp.h"
#include <vector.h>
#include "rxw.h"

class CMirror;
class CResult;
class CGrazerOptions;
class DDocument;
class CRelevance;
class CClot;
class CPunctParse;
class CFormatRaw;

class CFormDisplay : public CAbstractDisplay
{
public:
    CFormDisplay(CMirror &aMirror,
	   CResult &aResult,
	   CGrazerOptions &aOptions);
    virtual ~CFormDisplay();

    virtual void Display();

private:
    CMirror &Mirror;
    CResult &Result;
    CGrazerOptions &Options;
    CFileObj OutFile;
    int SkipClots;
    CPunctParse *PunctParse;
    vector<pair<short, CRegex> > TitleParts;
    CRegex TextCruft;
    const DString HiddenHead;

    vector<char> TextColor;
    vector<char> OccColor;

    void InitTitleParts();

    void DisplayUnindexed();
    void DisplayProlog();
    void DisplayEpilog();
    void DisplayDoc(DDocument *InDoc);
    void DisplayDocContents(DDocument *Doc);
    void DisplayRelevance(CRelevance *Relevance, double RelRes);
    int DisplayClot(CClot *Clot, int &HighlightCount);
    void DisplayPassage(const DString &Passage, 
        const char *Template);

    void ErrPrint(const vector<char> &Buffer);
    void OutPrint(const vector<char> &Buffer);

    int IsEmpty(const char *Name);

    vector<char>::const_iterator GetEscape(
	vector<char>::const_iterator Begin,
	vector<char>::const_iterator End);
    void PrintChars(
	vector<char>::const_iterator Begin,
	vector<char>::const_iterator End);
    void PrintEscape(vector<char>::const_iterator Escape);
    bool IsEscape(
	vector<char>::const_iterator Begin,
	vector<char>::const_iterator End);

    DString GetCleanText(const DString &RawText, const CRegex &Cruft);
    DString GetTail(const DString &DocFileName);

    void AddTitleText(CFormatRaw &Format, // in & out
        DDocument *Doc); // in
};

#endif
